summaryrefslogtreecommitdiff
path: root/include/cpu.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/cpu.h')
-rw-r--r--include/cpu.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/cpu.h b/include/cpu.h
index 78e88b9ed0..5831bfa742 100644
--- a/include/cpu.h
+++ b/include/cpu.h
@@ -8,7 +8,7 @@
#define __CPU_H
/**
* struct cpu_platdata - platform data for a CPU
* @cpu_id: Platform-specific way of identifying the CPU.
* @ucode_version: Microcode version, if CPU_FEAT_UCODE is set
* @device_id: Driver-defined device identifier
@@ -17,10 +17,10 @@
* @timebase_freq: the current frequency at which the cpu timer timebase
* registers are updated (in Hz)
*
* This can be accessed with dev_get_parent_platdata() for any UCLASS_CPU
* device.
*/
-struct cpu_platdata {
+struct cpu_plat {
int cpu_id;
int ucode_version;
ulong device_id;
@@ -8,7 +8,7 @@
#define __CPU_H
/**
- * struct cpu_platdata - platform data for a CPU
+ * struct cpu_plat - platform data for a CPU
* @cpu_id: Platform-specific way of identifying the CPU.
* @ucode_version: Microcode version, if CPU_FEAT_UCODE is set
@@ -17,10 +17,10 @@
* registers are updated (in Hz)
*
- * This can be accessed with dev_get_parent_platdata() for any UCLASS_CPU
+ * This can be accessed with dev_get_parent_plat() for any UCLASS_CPU
* device.
*/